



if not exist %LIBRARY_BIN%\\xrobot.exe (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_PREFIX%\\share\\jupyter\\kernels\\xrobot\\kernel.json (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\share\\jupyter\\kernels\\xrobot\\kernel.json (exit 1)
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
